==> dustpylib-0.4.0.tar.gz: dustpylib-0.4.0/README.md <==
# dustpylib

[![Documentation Status](https://readthedocs.org/projects/dustpylib/badge/?version=latest)](https://dustpylib.readthedocs.io/en/latest/?badge=latest) [![GitHub](https://img.shields.io/github/license/stammler/dustpylib)](https://github.com/stammler/dustpylib/blob/master/LICENSE) [![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.1-4baaaa.svg)](https://github.com/stammler/dustpylib/blob/master/.github/CODE_OF_CONDUCT.md)  
[![PyPI - Downloads](https://img.shields.io/pypi/dm/dustpylib?label=PyPI%20downloads)](https://pypistats.org/packages/dustpylib)


`dustpylib` is a library that contains auxiliary modules for the dust evolution software `DustPy`, for example interfaces to radiative transfer codes or modules with extensions to the `DustPy` defaults.

For information about the usage of ``DustPy``, please have a look at the [DustPy documentation](https://stammler.github.io/dustpy/).


## Installation

`dustpylib` can be installed via PyPI.

`pip install dustpylib`

## Documentation

For the usage of `dustpylib` please have a look at its [documentation](https://dustpylib.rtfd.io/).

* [Grid](https://dustpylib.readthedocs.io/en/latest/grid.html)
  - [Grid refinement](https://dustpylib.readthedocs.io/en/latest/grid_refinement.html)
* [Planetesimals](https://dustpylib.readthedocs.io/en/latest/planetesimals.html)
  - [Planetesimal formation](https://dustpylib.readthedocs.io/en/latest/planetesimal_formation.html)
* [Radiative transfer](https://dustpylib.readthedocs.io/en/latest/radtrans.html)
  - [RADMC-3D](https://dustpylib.readthedocs.io/en/latest/radmc3d.html)
* [Substructures](https://dustpylib.readthedocs.io/en/latest/substructures.html)
  - [Planetary gaps](https://dustpylib.readthedocs.io/en/latest/planetary_gaps.html)<br /> &nbsp;
* [A. Contributing / Bug reports / Features requests](https://dustpylib.readthedocs.io/en/latest/A_contrib_bug_feature.html)

==> dustpylib-0.6.0rc0.tar.gz: dustpylib-0.6.0rc0/README.md <==
# DustPyLib

[![Documentation Status](https://readthedocs.org/projects/dustpylib/badge/?version=latest)](https://dustpylib.readthedocs.io/en/latest/?badge=latest) [![GitHub](https://img.shields.io/github/license/stammler/dustpylib)](https://github.com/stammler/dustpylib/blob/master/LICENSE) [![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.1-4baaaa.svg)](https://github.com/stammler/dustpylib/blob/master/.github/CODE_OF_CONDUCT.md)  
[![PyPI - Downloads](https://img.shields.io/pypi/dm/dustpylib?label=PyPI%20downloads)](https://pypistats.org/packages/dustpylib)


`DustPyLib` is a library that contains auxiliary modules for the dust evolution software `DustPy`, for example interfaces to radiative transfer codes or modules with extensions to the `DustPy` defaults.

For information about the usage of `DustPy`, please have a look at the [DustPy documentation](https://stammler.github.io/dustpy/).


## Installation

`DustPyLib` can be installed via PyPI.

`pip install dustpylib`

## Documentation

For the usage of `DustPyLib` please have a look at its [documentation](https://dustpylib.rtfd.io/).

* [Grid](https://dustpylib.readthedocs.io/en/latest/grid.html)
  - [Grid refinement](https://dustpylib.readthedocs.io/en/latest/grid_refinement.html)
* [Planetesimals](https://dustpylib.readthedocs.io/en/latest/planetesimals.html)
  - [Planetesimal formation](https://dustpylib.readthedocs.io/en/latest/planetesimal_formation.html)
* [Radiative transfer](https://dustpylib.readthedocs.io/en/latest/radtrans.html)
  - [RADMC-3D](https://dustpylib.readthedocs.io/en/latest/radmc3d.html)
* [Substructures](https://dustpylib.readthedocs.io/en/latest/substructures.html)
  - [Planetary gaps](https://dustpylib.readthedocs.io/en/latest/planetary_gaps.html)<br /> &nbsp;
* [A. Contributing / Bug reports / Features requests](https://dustpylib.readthedocs.io/en/latest/A_contrib_bug_feature.html)
